@@ -1,4 +1,5 @@
 import os
+import re
 import sys
 from textwrap import dedent
 
@@ -42,7 +43,7 @@ class TestVenvConfig:
             deps=
                 world1
                 :xyz:http://hello/world
-        """ % (tmpdir, ))
+        """ % (tmpdir,))
         assert config.toxworkdir == tmpdir
         assert len(config.envconfigs) == 2
         assert config.envconfigs['py1'].envdir == tmpdir.join("py1")
@@ -95,7 +96,7 @@ class TestVenvConfig:
         assert config.option.force_dep == [
             'dep1==1.5', 'dep2==2.1', 'dep3==3.0']
         assert [str(x) for x in config.envconfigs['python'].deps] == [
-            'dep1==1.5', 'dep2==2.1', 'dep3==3.0', 'dep4==4.0',
+            'dep1==1.5', 'dep2==2.1', 'dep3==3.0', 'dep4==4.0'
         ]
 
     def test_force_dep_with_url(self, initproj):
@@ -118,6 +119,23 @@ class TestVenvConfig:
             'dep1==1.5', 'https://pypi.python.org/xyz/pkg1.tar.gz'
         ]
 
+    def test_process_deps(self, newconfig):
+        config = newconfig([], """
+            [testenv]
+            deps =
+                -r requirements.txt
+                --index-url https://pypi.org/simple
+                -fhttps://pypi.org/packages
+                --global-option=foo
+                -v dep1
+                --help dep2
+        """)  # note that those last two are invalid
+        assert [str(x) for x in config.envconfigs['python'].deps] == [
+            '-rrequirements.txt', '--index-url=https://pypi.org/simple',
+            '-fhttps://pypi.org/packages', '--global-option=foo',
+            '-v dep1', '--help dep2'
+        ]
+
     def test_is_same_dep(self):
         """
         Ensure correct parseini._is_same_dep is working with a few samples.
@@ -155,12 +173,12 @@ class TestConfigPlatform:
         monkeypatch.undo()
         assert not venv.matching_platform()
 
-    @pytest.mark.parametrize("plat", ["win", "lin", ])
+    @pytest.mark.parametrize("plat", ["win", "lin", "osx"])
     def test_config_parse_platform_with_factors(self, newconfig, plat, monkeypatch):
         monkeypatch.setattr(sys, "platform", "win32")
         config = newconfig([], """
             [tox]
-            envlist = py27-{win,lin,osx}
+            envlist = py27-{win, lin,osx }
             [testenv]
             platform =
                 win: win32
@@ -168,7 +186,7 @@ class TestConfigPlatform:
         """)
         assert len(config.envconfigs) == 3
         platform = config.envconfigs['py27-' + plat].platform
-        expected = {"win": "win32", "lin": "linux2"}.get(plat)
+        expected = {"win": "win32", "lin": "linux2", "osx": ""}.get(plat)
         assert platform == expected
 
 
@@ -296,7 +314,7 @@ class TestIniParserAgainstCommandsKey:
             "cmd2 param21 param22".split(),
             "cmd1 param11 param12".split(),
             "cmd2 param21 param22".split(),
-            ["echo", "cmd", "1", "2", "3", "4", "cmd", "2"],
+            ["echo", "cmd", "1", "2", "3", "4", "cmd", "2"]
         ]
 
     def test_command_substitution_from_other_section_posargs(self, newconfig):
@@ -509,8 +527,6 @@ class TestIniParser:
         """)
         reader = SectionReader("section", config._cfg)
         reader.addsubstitutions(item1="with space", item2="grr")
-        # pytest.raises(tox.exception.ConfigError,
-        #    "reader.getargvlist('key1')")
         assert reader.getargvlist('key1') == []
         x = reader.getargvlist("key2")
         assert x == [["cmd1", "with", "space", "grr"],
@@ -535,8 +551,6 @@ class TestIniParser:
         """)
         reader = SectionReader("section", config._cfg)
         reader.addsubstitutions(item1="with space", item2="grr")
-        # pytest.raises(tox.exception.ConfigError,
-        #    "reader.getargvlist('key1')")
         assert reader.getargvlist('key1') == []
         x = reader.getargvlist("key2")
         assert x == [["cmd1", "with", "space", "grr"]]
@@ -583,8 +597,6 @@ class TestIniParser:
         reader = SectionReader("section", config._cfg)
         posargs = ['hello', 'world']
         reader.addsubstitutions(posargs, item2="value2")
-        # pytest.raises(tox.exception.ConfigError,
-        #    "reader.getargvlist('key1')")
         assert reader.getargvlist('key1') == []
         argvlist = reader.getargvlist("key2")
         assert argvlist[0] == ["cmd1"] + posargs
@@ -592,8 +604,6 @@ class TestIniParser:
 
         reader = SectionReader("section", config._cfg)
         reader.addsubstitutions([], item2="value2")
-        # pytest.raises(tox.exception.ConfigError,
-        #    "reader.getargvlist('key1')")
         assert reader.getargvlist('key1') == []
         argvlist = reader.getargvlist("key2")
         assert argvlist[0] == ["cmd1"]
@@ -898,6 +908,7 @@ class TestConfigTestEnv:
             assert "TEMP" in envconfig.passenv
             assert "TMP" in envconfig.passenv
             assert "NUMBER_OF_PROCESSORS" in envconfig.passenv
+            assert "PROCESSOR_ARCHITECTURE" in envconfig.passenv
             assert "USERPROFILE" in envconfig.passenv
             assert "MSYSTEM" in envconfig.passenv
         else:
@@ -1005,7 +1016,7 @@ class TestConfigTestEnv:
             changedir=xyz
             [testenv:python]
             changedir=abc
-            basepython=python2.6
+            basepython=python3.6
         """)
         assert len(config.envconfigs) == 1
         envconfig = config.envconfigs['python']
@@ -1058,13 +1069,13 @@ class TestConfigTestEnv:
 
     def test_simple(tmpdir, newconfig):
         config = newconfig("""
-            [testenv:py26]
-            basepython=python2.6
+            [testenv:py36]
+            basepython=python3.6
             [testenv:py27]
             basepython=python2.7
         """)
         assert len(config.envconfigs) == 2
-        assert "py26" in config.envconfigs
+        assert "py36" in config.envconfigs
         assert "py27" in config.envconfigs
 
     def test_substitution_error(tmpdir, newconfig):
@@ -1128,7 +1139,7 @@ class TestConfigTestEnv:
         """)
         conf = config.envconfigs['standard-greeting']
         assert conf.commands == [
-            ['python', '-c', 'print("Hello, world!")'],
+            ['python', '-c', 'print("Hello, world!")']
         ]
 
     def test_substitution_nested_env_defaults(tmpdir, newconfig, monkeypatch):
@@ -1259,13 +1270,13 @@ class TestConfigTestEnv:
 
     @pytest.mark.parametrize('envlist, deps', [
         (['py27'], ('pytest', 'pytest-cov')),
-        (['py27', 'py34'], ('pytest', 'py{27,34}: pytest-cov')),
+        (['py27', 'py34'], ('pytest', 'py{27,34}: pytest-cov'))
     ])
     def test_take_dependencies_from_other_testenv(
-        self,
-        newconfig,
-        envlist,
-        deps
+            self,
+            newconfig,
+            envlist,
+            deps
     ):
         inisource = """
             [tox]
@@ -1367,12 +1378,20 @@ class TestConfigTestEnv:
                 a: dep-a
                 b: dep-b
                 x: dep-x
+                !a: dep-!a
+                !b: dep-!b
+                !x: dep-!x
         """
         conf = newconfig([], inisource)
         configs = conf.envconfigs
-        assert [dep.name for dep in configs['a-x'].deps] == \
-            ["dep-all", "dep-a", "dep-x"]
-        assert [dep.name for dep in configs['b'].deps] == ["dep-all", "dep-b"]
+        expected = ["dep-all", "dep-a", "dep-x", "dep-!b"]
+        assert [dep.name for dep in configs['a-x'].deps] == expected
+        expected = ["dep-all", "dep-b", "dep-!a", "dep-!x"]
+        assert [dep.name for dep in configs['b'].deps] == expected
+        expected = ["dep-all", "dep-a", "dep-x", "dep-!b"]
+        assert [dep.name for dep in configs['a-x'].deps] == expected
+        expected = ["dep-all", "dep-b", "dep-!a", "dep-!x"]
+        assert [dep.name for dep in configs['b'].deps] == expected
 
     def test_factor_ops(self, newconfig):
         inisource = """
@@ -1384,21 +1403,60 @@ class TestConfigTestEnv:
                 a,b: dep-a-or-b
                 a-x: dep-a-and-x
                 {a,b}-y: dep-ab-and-y
+                a-!x: dep-a-and-!x
+                a,!x: dep-a-or-!x
+                !a-!x: dep-!a-and-!x
+                !a,!x: dep-!a-or-!x
+                !a-!b: dep-!a-and-!b
+                !a-!b-!x-!y: dep-!a-and-!b-and-!x-and-!y
         """
         configs = newconfig([], inisource).envconfigs
 
         def get_deps(env):
             return [dep.name for dep in configs[env].deps]
 
-        assert get_deps("a-x") == ["dep-a-or-b", "dep-a-and-x"]
-        assert get_deps("a-y") == ["dep-a-or-b", "dep-ab-and-y"]
-        assert get_deps("b-x") == ["dep-a-or-b"]
-        assert get_deps("b-y") == ["dep-a-or-b", "dep-ab-and-y"]
+        assert get_deps("a-x") == ["dep-a-or-b", "dep-a-and-x", "dep-a-or-!x"]
+        assert get_deps("a-y") == ["dep-a-or-b", "dep-ab-and-y",
+                                   "dep-a-and-!x", "dep-a-or-!x",
+                                   "dep-!a-or-!x"]
+        assert get_deps("b-x") == ["dep-a-or-b", "dep-!a-or-!x"]
+        assert get_deps("b-y") == ["dep-a-or-b", "dep-ab-and-y", "dep-a-or-!x",
+                                   "dep-!a-and-!x", "dep-!a-or-!x"]
+
+    def test_envconfigs_based_on_factors(self, newconfig):
+        inisource = """
+            [testenv]
+            some-setting=
+                a: something
+                b,c: something
+                d-e: something
+                !f: something
+                !g,!h: something
+                !i-!j: something
+
+            [unknown-section]
+            some-setting=
+                eggs: something
+        """
+        config = newconfig(["-e spam"], inisource)
+        assert not config.envconfigs
+        assert config.envlist == ["spam"]
+        config = newconfig(["-e eggs"], inisource)
+        assert not config.envconfigs
+        assert config.envlist == ["eggs"]
+        config = newconfig(["-e py3-spam"], inisource)
+        assert not config.envconfigs
+        assert config.envlist == ["py3-spam"]
+        for x in "abcdefghij":
+            env = "py3-{}".format(x)
+            config = newconfig(["-e {}".format(env)], inisource)
+            assert sorted(config.envconfigs) == [env]
+            assert config.envlist == [env]
 
     def test_default_factors(self, newconfig):
         inisource = """
             [tox]
-            envlist = py{26,27,33,34}-dep
+            envlist = py{27,34,36}-dep
 
             [testenv]
             deps=
@@ -1413,7 +1471,7 @@ class TestConfigTestEnv:
     def test_factors_in_boolean(self, newconfig):
         inisource = """
             [tox]
-            envlist = py{27,33}
+            envlist = py{27,36}
 
             [testenv]
             recreate =
@@ -1421,13 +1479,13 @@ class TestConfigTestEnv:
         """
         configs = newconfig([], inisource).envconfigs
         assert configs["py27"].recreate
-        assert not configs["py33"].recreate
+        assert not configs["py36"].recreate
 
     @pytest.mark.issue190
     def test_factors_in_setenv(self, newconfig):
         inisource = """
             [tox]
-            envlist = py27,py26
+            envlist = py27,py36
 
             [testenv]
             setenv =
@@ -1435,7 +1493,7 @@ class TestConfigTestEnv:
         """
         configs = newconfig([], inisource).envconfigs
         assert configs["py27"].setenv["X"] == "1"
-        assert "X" not in configs["py26"].setenv
+        assert "X" not in configs["py36"].setenv
 
     @pytest.mark.issue191
     def test_factor_use_not_checked(self, newconfig):
@@ -1447,7 +1505,7 @@ class TestConfigTestEnv:
             deps = b: test
         """
         configs = newconfig([], inisource).envconfigs
-        assert set(configs.keys()) == set(['py27-a', 'py27-b'])
+        assert set(configs.keys()) == {'py27-a', 'py27-b'}
 
     @pytest.mark.issue198
     def test_factors_groups_touch(self, newconfig):
@@ -1460,7 +1518,7 @@ class TestConfigTestEnv:
                 a,b,x,y: dep
         """
         configs = newconfig([], inisource).envconfigs
-        assert set(configs.keys()) == set(['a', 'a-x', 'b', 'b-x'])
+        assert set(configs.keys()) == {'a', 'a-x', 'b', 'b-x'}
 
     def test_period_in_factor(self, newconfig):
         inisource = """
@@ -1474,8 +1532,7 @@ class TestConfigTestEnv:
         """
         configs = newconfig([], inisource).envconfigs
         assert sorted(configs) == ["py27-django1.6", "py27-django1.7"]
-        assert [d.name for d in configs["py27-django1.6"].deps] \
-            == ["Django==1.6"]
+        assert [d.name for d in configs["py27-django1.6"].deps] == ["Django==1.6"]
 
     def test_ignore_outcome(self, newconfig):
         inisource = """
@@ -1495,11 +1552,21 @@ class TestGlobalOptions:
 
     def test_verbosity(self, newconfig):
         config = newconfig([], "")
-        assert config.option.verbosity == 0
+        assert config.option.verbose_level == 0
         config = newconfig(["-v"], "")
-        assert config.option.verbosity == 1
+        assert config.option.verbose_level == 1
         config = newconfig(["-vv"], "")
-        assert config.option.verbosity == 2
+        assert config.option.verbose_level == 2
+
+    @pytest.mark.parametrize('args, expected', [
+        ([], 0),
+        (["-q"], 1),
+        (["-qq"], 2),
+        (["-qqq"], 3),
+    ])
+    def test_quiet(self, args, expected, newconfig):
+        config = newconfig(args, "")
+        assert config.option.quiet_level == expected
 
     def test_substitution_jenkins_default(self, tmpdir,
                                           monkeypatch, newconfig):
@@ -1541,28 +1608,28 @@ class TestGlobalOptions:
     def test_env_selection(self, tmpdir, newconfig, monkeypatch):
         inisource = """
             [tox]
-            envlist = py26
-            [testenv:py26]
-            basepython=python2.6
-            [testenv:py31]
-            basepython=python3.1
+            envlist = py36
+            [testenv:py36]
+            basepython=python3.6
+            [testenv:py35]
+            basepython=python3.5
             [testenv:py27]
             basepython=python2.7
         """
-        # pytest.raises(tox.exception.ConfigError,
-        #    "newconfig(['-exyz'], inisource)")
         config = newconfig([], inisource)
-        assert config.envlist == ["py26"]
-        config = newconfig(["-epy31"], inisource)
-        assert config.envlist == ["py31"]
-        monkeypatch.setenv("TOXENV", "py31,py26")
+        assert config.envlist == ["py36"]
+        config = newconfig(["-epy35"], inisource)
+        assert config.envlist == ["py35"]
+        monkeypatch.setenv("TOXENV", "py35,py36")
         config = newconfig([], inisource)
-        assert config.envlist == ["py31", "py26"]
+        assert config.envlist == ["py35", "py36"]
         monkeypatch.setenv("TOXENV", "ALL")
         config = newconfig([], inisource)
-        assert config.envlist == ['py26', 'py27', 'py31']
+        assert config.envlist == ['py27', 'py35', 'py36']
         config = newconfig(["-eALL"], inisource)
-        assert config.envlist == ['py26', 'py27', 'py31']
+        assert config.envlist == ['py27', 'py35', 'py36']
+        config = newconfig(['-espam'], inisource)
+        assert config.envlist == ["spam"]
 
     def test_py_venv(self, tmpdir, newconfig, monkeypatch):
         config = newconfig(["-epy"], "")
@@ -1570,7 +1637,7 @@ class TestGlobalOptions:
         assert str(env.basepython) == sys.executable
 
     def test_default_environments(self, tmpdir, newconfig, monkeypatch):
-        envs = "py26,py27,py32,py33,py34,py35,py36,py37,jython,pypy,pypy3,py2,py3"
+        envs = "py27,py34,py35,py36,py37,jython,pypy,pypy3,py2,py3"
         inisource = """
             [tox]
             envlist = %s
@@ -1594,19 +1661,19 @@ class TestGlobalOptions:
     def test_envlist_expansion(self, newconfig):
         inisource = """
             [tox]
-            envlist = py{26,27},docs
+            envlist = py{36,27},docs
         """
         config = newconfig([], inisource)
-        assert config.envlist == ["py26", "py27", "docs"]
+        assert config.envlist == ["py36", "py27", "docs"]
 
     def test_envlist_cross_product(self, newconfig):
         inisource = """
             [tox]
-            envlist = py{26,27}-dep{1,2}
+            envlist = py{36,27}-dep{1,2}
         """
         config = newconfig([], inisource)
-        assert config.envlist == \
-            ["py26-dep1", "py26-dep2", "py27-dep1", "py27-dep2"]
+        envs = ["py36-dep1", "py36-dep2", "py27-dep1", "py27-dep2"]
+        assert config.envlist == envs
 
     def test_envlist_multiline(self, newconfig):
         inisource = """
@@ -1616,8 +1683,7 @@ class TestGlobalOptions:
               py34
         """
         config = newconfig([], inisource)
-        assert config.envlist == \
-            ["py27", "py34"]
+        assert config.envlist == ["py27", "py34"]
 
     def test_minversion(self, tmpdir, newconfig, monkeypatch):
         inisource = """
@@ -1673,7 +1739,6 @@ class TestHashseedOption:
                 [testenv]
             """
         if make_hashseed is None:
-
             def make_hashseed():
                 return '123456789'
 
@@ -1755,11 +1820,13 @@ class TestHashseedOption:
             [testenv:hash2]
         """
         next_seed = [1000]
+
         # This function is guaranteed to generate a different value each time.
 
         def make_hashseed():
             next_seed[0] += 1
             return str(next_seed[0])
+
         # Check that make_hashseed() works.
         assert make_hashseed() == '1001'
         envconfigs = self._get_envconfigs(newconfig, tox_ini=tox_ini,
@@ -2020,18 +2087,16 @@ class TestParseEnv:
 
 class TestCmdInvocation:
     def test_help(self, cmd):
-        result = cmd.run("tox", "-h")
+        result = cmd("-h")
         assert not result.ret
-        result.stdout.fnmatch_lines([
-            "*help*",
-        ])
+        assert not result.err
+        assert re.match(r'usage:.*help.*', result.out, re.DOTALL)
 
     def test_version_simple(self, cmd):
-        result = cmd.run("tox", "--version")
+        result = cmd("--version")
         assert not result.ret
-        stdout = result.stdout.str()
-        assert tox.__version__ in stdout
-        assert "imported from" in stdout
+        from tox import __version__
+        assert "{} imported from".format(__version__) in result.out
 
     def test_version_no_plugins(self):
         pm = PluginManager('fakeprject')
@@ -2047,6 +2112,7 @@ class TestCmdInvocation:
             class MockEggInfo:
                 project_name = 'some-project'
                 version = '1.0'
+
             return [(MockModule, MockEggInfo)]
 
         pm = PluginManager('fakeproject')
@@ -2067,6 +2133,7 @@ class TestCmdInvocation:
             class MockEggInfo:
                 project_name = 'some-project'
                 version = '1.0'
+
             return [(MockModule(), MockEggInfo)]
 
         pm = PluginManager('fakeproject')
@@ -2082,9 +2149,9 @@ class TestCmdInvocation:
         initproj('listenvs', filedefs={
             'tox.ini': '''
             [tox]
-            envlist=py26,py27,py33,pypy,docs
+            envlist=py36,py27,py34,pypy,docs
             description= py27: run pytest on Python 2.7
-                         py33: run pytest on Python 3.6
+                         py34: run pytest on Python 3.6
                          pypy: publish to pypy
                          docs: document stuff
                          notincluded: random extra
@@ -2094,26 +2161,20 @@ class TestCmdInvocation:
 
             [testenv:docs]
             changedir = docs
-            ''',
+            '''
         })
-        result = cmd.run("tox", "-l")
-        result.stdout.fnmatch_lines("""
-            py26
-            py27
-            py33
-            pypy
-            docs
-        """)
+        result = cmd("-l")
+        assert result.outlines == ['py36', 'py27', 'py34', 'pypy', 'docs']
 
     def test_listenvs_verbose_description(self, cmd, initproj):
         initproj('listenvs_verbose_description', filedefs={
             'tox.ini': '''
             [tox]
-            envlist=py26,py27,py33,pypy,docs
+            envlist=py36,py27,py34,pypy,docs
             [testenv]
-            description= py26: run pytest on Python 2.6
+            description= py36: run pytest on Python 3.6
                          py27: run pytest on Python 2.7
-                         py33: run pytest on Python 3.3
+                         py34: run pytest on Python 3.4
                          pypy: publish to pypy
                          docs: document stuff
                          notincluded: random extra
@@ -2124,46 +2185,38 @@ class TestCmdInvocation:
             [testenv:docs]
             changedir = docs
             description = let me overwrite that
-            ''',
+            '''
         })
-        result = cmd.run("tox", "-lv")
-        result.stdout.fnmatch_lines("""
-            default environments:
-            py26 -> run pytest on Python 2.6
-            py27 -> run pytest on Python 2.7
-            py33 -> run pytest on Python 3.3
-            pypy -> publish to pypy
-            docs -> let me overwrite that
-        """)
+        result = cmd("-lv")
+        assert result.outlines[2:] == [
+            'default environments:',
+            'py36 -> run pytest on Python 3.6',
+            'py27 -> run pytest on Python 2.7',
+            'py34 -> run pytest on Python 3.4',
+            'pypy -> publish to pypy',
+            'docs -> let me overwrite that']
 
     def test_listenvs_all(self, cmd, initproj):
         initproj('listenvs_all', filedefs={
             'tox.ini': '''
             [tox]
-            envlist=py26,py27,py33,pypy,docs
+            envlist=py36,py27,py34,pypy,docs
 
             [testenv:notincluded]
             changedir = whatever
 
             [testenv:docs]
             changedir = docs
-            ''',
+            '''
         })
-        result = cmd.run("tox", "-a")
-        result.stdout.fnmatch_lines("""
-            py26
-            py27
-            py33
-            pypy
-            docs
-            notincluded
-        """)
+        result = cmd("-a")
+        assert result.outlines == ['py36', 'py27', 'py34', 'pypy', 'docs', 'notincluded']
 
     def test_listenvs_all_verbose_description(self, cmd, initproj):
         initproj('listenvs_all_verbose_description', filedefs={
             'tox.ini': '''
             [tox]
-            envlist={py27,py36}-{windows,linux}
+            envlist={py27,py36}-{windows,linux} # py35
             [testenv]
             description= py27: run pytest on Python 2.7
                          py36: run pytest on Python 3.6
@@ -2176,48 +2229,44 @@ class TestCmdInvocation:
             changedir = docs
             ''',
         })
-        result = cmd.run("tox", "-av")
-        result.stdout.fnmatch_lines("""
-            default environments:
-            py27-windows -> run pytest on Python 2.7 on Windows platform
-            py27-linux   -> run pytest on Python 2.7 on Linux platform
-            py36-windows -> run pytest on Python 3.6 on Windows platform
-            py36-linux   -> run pytest on Python 3.6 on Linux platform
-
-            additional environments:
-            docs         -> generate documentation
-        """)
+        result = cmd("-av")
+        expected = [
+            "default environments:",
+            "py27-windows -> run pytest on Python 2.7 on Windows platform",
+            "py27-linux   -> run pytest on Python 2.7 on Linux platform",
+            "py36-windows -> run pytest on Python 3.6 on Windows platform",
+            "py36-linux   -> run pytest on Python 3.6 on Linux platform",
+            "",
+            "additional environments:",
+            "docs         -> generate documentation"]
+        assert result.outlines[-len(expected):] == expected
 
     def test_listenvs_all_verbose_description_no_additional_environments(self, cmd, initproj):
         initproj('listenvs_all_verbose_description', filedefs={
             'tox.ini': '''
             [tox]
             envlist=py27,py36
-            ''',
+            '''
         })
-        result = cmd.run("tox", "-av")
-        result.stdout.fnmatch_lines("""
-            default environments:
-            py27 -> [no description]
-            py36 -> [no description]
-        """)
-        assert 'additional environments' not in result.stdout.str()
+        result = cmd("-av")
+        expected = ["default environments:",
+                    "py27 -> [no description]",
+                    "py36 -> [no description]"]
+        assert result.out.splitlines()[-3:] == expected
+        assert 'additional environments' not in result.out
 
     def test_config_specific_ini(self, tmpdir, cmd):
         ini = tmpdir.ensure("hello.ini")
-        result = cmd.run("tox", "-c", ini, "--showconfig")
+        result = cmd("-c", ini, "--showconfig")
         assert not result.ret
-        result.stdout.fnmatch_lines([
-            "*config-file*hello.ini*",
-        ])
+        assert result.outlines[1] == 'config-file: {}'.format(ini)
 
     def test_no_tox_ini(self, cmd, initproj):
         initproj("noini-0.5", )
-        result = cmd.run("tox")
+        result = cmd()
         assert result.ret
-        result.stderr.fnmatch_lines([
-            "*ERROR*tox.ini*not*found*",
-        ])
+        assert result.out == ''
+        assert result.err == "ERROR: toxini file 'tox.ini' not found\n"
 
     def test_override_workdir(self, tmpdir, cmd, initproj):
         baddir = "badworkdir-123"
@@ -2228,11 +2277,10 @@ class TestCmdInvocation:
             toxworkdir=%s
             ''' % baddir,
         })
-        result = cmd.run("tox", "--workdir", gooddir, "--showconfig")
+        result = cmd("--workdir", gooddir, "--showconfig")
         assert not result.ret
-        stdout = result.stdout.str()
-        assert gooddir in stdout
-        assert baddir not in stdout
+        assert gooddir in result.out
+        assert baddir not in result.out
         assert py.path.local(gooddir).check()
         assert not py.path.local(baddir).check()
 
@@ -2247,18 +2295,14 @@ class TestCmdInvocation:
                 dep2
             ''',
         })
-        result = cmd.run("tox", "--showconfig")
+        result = cmd("--showconfig")
         assert result.ret == 0
-        result.stdout.fnmatch_lines([
-            r'*deps*dep1==2.3, dep2*',
-        ])
+        assert any(re.match(r'.*deps.*dep1==2.3, dep2.*', l) for l in result.outlines)
         # override dep1 specific version, and force version for dep2
-        result = cmd.run("tox", "--showconfig", "--force-dep=dep1",
-                         "--force-dep=dep2==5.0")
+        result = cmd("--showconfig", "--force-dep=dep1",
+                     "--force-dep=dep2==5.0")
         assert result.ret == 0
-        result.stdout.fnmatch_lines([
-            r'*deps*dep1, dep2==5.0*',
-        ])
+        assert any(re.match(r'.*deps.*dep1, dep2==5.0.*', l) for l in result.outlines)
 
     @pytest.mark.xfail(
         "'pypy' not in sys.executable",
@@ -2271,17 +2315,17 @@ class TestCmdInvocation:
 
             [testenv]
             commands = pip --version
-            ''',
+            '''
         })
-        result = cmd.run("tox")
+        result = cmd()
         assert result.ret == 0
 
 
 @pytest.mark.parametrize("cmdline,envlist", [
-    ("-e py26", ['py26']),
-    ("-e py26,py33", ['py26', 'py33']),
-    ("-e py26,py26", ['py26', 'py26']),
-    ("-e py26,py33 -e py33,py27", ['py26', 'py33', 'py33', 'py27'])
+    ("-e py36", ['py36']),
+    ("-e py36,py34", ['py36', 'py34']),
+    ("-e py36,py36", ['py36', 'py36']),
+    ("-e py36,py34 -e py34,py27", ['py36', 'py34', 'py34', 'py27'])
 ])
 def test_env_spec(cmdline, envlist):
     args = cmdline.split()
@@ -2293,7 +2337,6 @@ class TestCommandParser:
 
     def test_command_parser_for_word(self):
         p = CommandParser('word')
-        # import pytest; pytest.set_trace()
         assert list(p.words()) == ['word']
 
     def test_command_parser_for_posargs(self):
@@ -2318,7 +2361,7 @@ class TestCommandParser:
             'word', ' ', '[]', ' ', '[literal]', ' ', '{something}', ' ', '{some:other thing}',
             ' ', 'w', '{ord}', ' ', 'w', '{or}', 'd', ' ', 'w', '{ord}', ' ', 'w', '{o:rd}', ' ',
             'w', '{o:r}', 'd', ' ', '{w:or}', 'd',
-            ' ', 'w[]ord', ' ', '{posargs:{a key}}',
+            ' ', 'w[]ord', ' ', '{posargs:{a key}}'
         ]
 
         assert parsed == expected
@@ -2348,8 +2391,8 @@ class TestCommandParser:
     @pytest.mark.skipif("sys.platform != 'win32'")
     def test_commands_with_backslash(self, newconfig):
         config = newconfig([r"hello\world"], """
-            [testenv:py26]
+            [testenv:py36]
             commands = some {posargs}
         """)
-        envconfig = config.envconfigs["py26"]
+        envconfig = config.envconfigs["py36"]
         assert envconfig.commands[0] == ["some", r"hello\world"]
