@@ -1,10 +1,15 @@
+import os
 import platform
+import re
+import subprocess
+import sys
 
 import py
 import pytest
 
 import tox
 from tox._pytestplugin import ReportExpectMock
+
 try:
     import json
 except ImportError:
@@ -178,11 +183,9 @@ def XXX_test_package(cmd, initproj):
             """,
         'tox.ini': ''
     })
-    result = cmd.run("tox", "package")
+    result = cmd("package")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*created sdist package at*",
-    ])
+    assert any(re.match(r'.*created sdist package at.*', l) for l in result.outlines)
 
 
 def test_minversion(cmd, initproj):
@@ -193,10 +196,9 @@ def test_minversion(cmd, initproj):
             minversion = 6.0
         '''
     })
-    result = cmd.run("tox", "-v")
-    result.stdout.fnmatch_lines([
-        "*ERROR*tox version is * required is at least 6.0*"
-    ])
+    result = cmd("-v")
+    assert re.match(r'ERROR: MinVersionError: tox version is .*,'
+                    r' required is at least 6.0', result.out)
     assert result.ret
 
 
@@ -204,13 +206,10 @@ def test_notoxini_help_still_works(initproj, cmd):
     initproj("example123-0.5", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
     })
-    result = cmd.run("tox", "-h")
-    result.stderr.fnmatch_lines([
-        "*ERROR*tox.ini*"
-    ])
-    result.stdout.fnmatch_lines([
-        "*--help*"
-    ])
+    result = cmd("-h")
+    assert result.err == "ERROR: toxini file 'tox.ini' not found\n"
+    assert result.out.startswith('usage: ')
+    assert any('--help' in l for l in result.outlines)
     assert not result.ret
 
 
@@ -218,13 +217,8 @@ def test_notoxini_help_ini_still_works(initproj, cmd):
     initproj("example123-0.5", filedefs={
         'tests': {'test_hello.py': "def test_hello(): pass"},
     })
-    result = cmd.run("tox", "--help-ini")
-    result.stderr.fnmatch_lines([
-        "*ERROR*tox.ini*"
-    ])
-    result.stdout.fnmatch_lines([
-        "*setenv*"
-    ])
+    result = cmd("--help-ini")
+    assert any('setenv' in l for l in result.outlines)
     assert not result.ret
 
 
@@ -235,11 +229,9 @@ def test_envdir_equals_toxini_errors_out(cmd, initproj):
             envdir={toxinidir}
         '''
     })
-    result = cmd.run("tox")
-    result.stdout.fnmatch_lines([
-        "ERROR*venv*delete*",
-        "*ConfigError*envdir must not equal toxinidir*",
-    ])
+    result = cmd()
+    assert result.outlines[1] == "ERROR: ConfigError: envdir must not equal toxinidir"
+    assert re.match(r'ERROR: venv \'python\' in .* would delete project', result.outlines[0])
     assert result.ret
 
 
@@ -250,10 +242,9 @@ def test_run_custom_install_command_error(cmd, initproj):
             install_command=./tox.ini {opts} {packages}
         '''
     })
-    result = cmd.run("tox")
-    result.stdout.fnmatch_lines([
-        "ERROR: invocation failed (errno *), args: ['*/tox.ini*",
-    ])
+    result = cmd()
+    assert re.match(r"ERROR: invocation failed \(errno \d+\), args: \['.*[/\\]tox\.ini",
+                    result.outlines[-1])
     assert result.ret
 
 
@@ -267,17 +258,13 @@ def test_unknown_interpreter_and_env(cmd, initproj):
             changedir=tests
         '''
     })
-    result = cmd.run("tox")
+    result = cmd()
     assert result.ret
-    result.stdout.fnmatch_lines([
-        "*ERROR*InterpreterNotFound*xyz_unknown_interpreter*",
-    ])
+    assert any('ERROR: InterpreterNotFound: xyz_unknown_interpreter' == l for l in result.outlines)
 
-    result = cmd.run("tox", "-exyz")
+    result = cmd("-exyz")
     assert result.ret
-    result.stdout.fnmatch_lines([
-        "*ERROR*unknown*",
-    ])
+    assert result.out == "ERROR: unknown environment 'xyz'\n"
 
 
 def test_unknown_interpreter(cmd, initproj):
@@ -290,11 +277,9 @@ def test_unknown_interpreter(cmd, initproj):
             changedir=tests
         '''
     })
-    result = cmd.run("tox")
+    result = cmd()
     assert result.ret
-    result.stdout.fnmatch_lines([
-        "*ERROR*InterpreterNotFound*xyz_unknown_interpreter*",
-    ])
+    assert any('ERROR: InterpreterNotFound: xyz_unknown_interpreter' == l for l in result.outlines)
 
 
 def test_skip_platform_mismatch(cmd, initproj):
@@ -306,11 +291,9 @@ def test_skip_platform_mismatch(cmd, initproj):
             platform=x123
         '''
     })
-    result = cmd.run("tox")
+    result = cmd()
     assert not result.ret
-    result.stdout.fnmatch_lines("""
-        SKIPPED*platform mismatch*
-    """)
+    assert any('SKIPPED:  python: platform mismatch' == l for l in result.outlines)
 
 
 def test_skip_unknown_interpreter(cmd, initproj):
@@ -323,11 +306,31 @@ def test_skip_unknown_interpreter(cmd, initproj):
             changedir=tests
         '''
     })
-    result = cmd.run("tox", "--skip-missing-interpreters")
+    result = cmd("--skip-missing-interpreters")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*SKIPPED*InterpreterNotFound*xyz_unknown_interpreter*",
-    ])
+    msg = 'SKIPPED:  python: InterpreterNotFound: xyz_unknown_interpreter'
+    assert any(msg == l for l in result.outlines)
+
+
+def test_skip_unknown_interpreter_result_json(cmd, initproj, tmpdir):
+    report_path = tmpdir.join("toxresult.json")
+    initproj("interp123-0.5", filedefs={
+        'tests': {'test_hello.py': "def test_hello(): pass"},
+        'tox.ini': '''
+            [testenv:python]
+            basepython=xyz_unknown_interpreter
+            [testenv]
+            changedir=tests
+        '''
+    })
+    result = cmd("--skip-missing-interpreters", "--result-json", report_path)
+    assert not result.ret
+    msg = 'SKIPPED:  python: InterpreterNotFound: xyz_unknown_interpreter'
+    assert any(msg == l for l in result.outlines)
+    setup_result_from_json = json.load(report_path)["testenvs"]["python"]["setup"]
+    for setup_step in setup_result_from_json:
+        assert "InterpreterNotFound" in setup_step["output"]
+        assert setup_step["retcode"] == "0"
 
 
 def test_unknown_dep(cmd, initproj):
@@ -339,11 +342,9 @@ def test_unknown_dep(cmd, initproj):
             changedir=tests
         '''
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret
-    result.stdout.fnmatch_lines([
-        "*ERROR*could not install*qweqwe123*",
-    ])
+    assert result.outlines[-1].startswith('ERROR:   python: could not install deps [qweqwe123];')
 
 
 def test_venv_special_chars_issue252(cmd, initproj):
@@ -356,22 +357,19 @@ def test_venv_special_chars_issue252(cmd, initproj):
             changedir=tests
         '''
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret == 0
-    result.stdout.fnmatch_lines([
-        "*installed*pkg123*"
-    ])
+    pattern = re.compile('special&&1 installed: .*pkg123==0.7.*')
+    assert any(pattern.match(line) for line in result.outlines)
 
 
 def test_unknown_environment(cmd, initproj):
     initproj("env123-0.7", filedefs={
         'tox.ini': ''
     })
-    result = cmd.run("tox", "-e", "qpwoei")
+    result = cmd("-e", "qpwoei")
     assert result.ret
-    result.stdout.fnmatch_lines([
-        "*ERROR*unknown*environment*qpwoei*",
-    ])
+    assert result.out == "ERROR: unknown environment 'qpwoei'\n"
 
 
 def test_skip_sdist(cmd, initproj):
@@ -387,7 +385,7 @@ def test_skip_sdist(cmd, initproj):
             commands=python -c "print('done')"
         '''
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret == 0
 
 
@@ -397,13 +395,10 @@ def test_minimal_setup_py_empty(cmd, initproj):
         'setup.py': """
         """,
         'tox.ini': ''
-
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret == 1
-    result.stdout.fnmatch_lines([
-        "*ERROR*empty*",
-    ])
+    assert result.outlines[-1] == 'ERROR: setup.py is empty'
 
 
 def test_minimal_setup_py_comment_only(cmd, initproj):
@@ -415,11 +410,9 @@ def test_minimal_setup_py_comment_only(cmd, initproj):
         'tox.ini': ''
 
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret == 1
-    result.stdout.fnmatch_lines([
-        "*ERROR*empty*",
-    ])
+    assert result.outlines[-1] == 'ERROR: setup.py is empty'
 
 
 def test_minimal_setup_py_non_functional(cmd, initproj):
@@ -432,11 +425,9 @@ def test_minimal_setup_py_non_functional(cmd, initproj):
         'tox.ini': ''
 
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret == 1
-    result.stdout.fnmatch_lines([
-        "*ERROR*check setup.py*",
-    ])
+    assert any(re.match(r'.*ERROR.*check setup.py.*', l) for l in result.outlines)
 
 
 def test_sdist_fails(cmd, initproj):
@@ -447,11 +438,22 @@ def test_sdist_fails(cmd, initproj):
         """,
         'tox.ini': '',
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret
-    result.stdout.fnmatch_lines([
-        "*FAIL*could not package project*",
-    ])
+    assert any(re.match(r'.*FAIL.*could not package project.*', l) for l in result.outlines)
+
+
+def test_no_setup_py_exits(cmd, initproj):
+    initproj("pkg123-0.7", filedefs={
+        'tox.ini': """
+            [testenv]
+            commands=python -c "2 + 2"
+        """
+    })
+    os.remove("setup.py")
+    result = cmd()
+    assert result.ret
+    assert any(re.match(r'.*ERROR.*No setup.py file found.*', l) for l in result.outlines)
 
 
 def test_package_install_fails(cmd, initproj):
@@ -471,81 +473,73 @@ def test_package_install_fails(cmd, initproj):
             """,
         'tox.ini': '',
     })
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret
-    result.stdout.fnmatch_lines([
-        "*InvocationError*",
-    ])
+    assert result.outlines[-1].startswith('ERROR:   python: InvocationError for command ')
 
 
-class TestToxRun:
-    @pytest.fixture
-    def example123(self, initproj):
-        initproj("example123-0.5", filedefs={
-            'tests': {
-                'test_hello.py': """
-                    def test_hello(pytestconfig):
-                        pass
-                """,
-            },
-            'tox.ini': '''
-                [testenv]
-                changedir=tests
-                commands= pytest --basetemp={envtmpdir} \
-                                  --junitxml=junit-{envname}.xml
-                deps=pytest
-            '''
-        })
-
-    def test_toxuone_env(self, cmd, example123):
-        result = cmd.run("tox")
-        assert not result.ret
-        result.stdout.fnmatch_lines([
-            "*junit-python.xml*",
-            "*1 passed*",
-        ])
-        result = cmd.run("tox", "-epython", )
-        assert not result.ret
-        result.stdout.fnmatch_lines([
-            "*1 passed*",
-            "*summary*",
-            "*python: commands succeeded"
-        ])
-
-    def test_different_config_cwd(self, cmd, example123, monkeypatch):
-        # see that things work with a different CWD
-        monkeypatch.chdir(cmd.tmpdir)
-        result = cmd.run("tox", "-c", "example123/tox.ini")
-        assert not result.ret
-        result.stdout.fnmatch_lines([
-            "*1 passed*",
-            "*summary*",
-            "*python: commands succeeded"
-        ])
-
-    def test_json(self, cmd, example123):
-        # see that tests can also fail and retcode is correct
-        testfile = py.path.local("tests").join("test_hello.py")
-        assert testfile.check()
-        testfile.write("def test_fail(): assert 0")
-        jsonpath = cmd.tmpdir.join("res.json")
-        result = cmd.run("tox", "--result-json", jsonpath)
-        assert result.ret == 1
-        data = json.load(jsonpath.open("r"))
-        verify_json_report_format(data)
-        result.stdout.fnmatch_lines([
-            "*1 failed*",
-            "*summary*",
-            "*python: *failed*",
-        ])
+@pytest.fixture
+def example123(initproj):
+    yield initproj("example123-0.5", filedefs={
+        'tests': {
+            'test_hello.py': """
+                def test_hello(pytestconfig):
+                    pass
+            """,
+        },
+        'tox.ini': '''
+            [testenv]
+            changedir=tests
+            commands= pytest --basetemp={envtmpdir} \
+                              --junitxml=junit-{envname}.xml
+            deps=pytest
+        '''
+    })
 
 
-def test_develop(initproj, cmd):
+def test_toxuone_env(cmd, example123):
+    result = cmd()
+    assert not result.ret
+    assert re.match(r'.*generated\W+xml\W+file.*junit-python\.xml'
+                    r'.*\W+1\W+passed.*', result.out, re.DOTALL)
+    result = cmd("-epython", )
+    assert not result.ret
+    assert re.match(r'.*\W+1\W+passed.*'
+                    r'summary.*'
+                    r'python:\W+commands\W+succeeded.*', result.out, re.DOTALL)
+
+
+def test_different_config_cwd(cmd, example123, monkeypatch):
+    # see that things work with a different CWD
+    monkeypatch.chdir(example123.dirname)
+    result = cmd("-c", "example123/tox.ini")
+    assert not result.ret
+    assert re.match(r'.*\W+1\W+passed.*'
+                    r'summary.*'
+                    r'python:\W+commands\W+succeeded.*', result.out, re.DOTALL)
+
+
+def test_json(cmd, example123):
+    # see that tests can also fail and retcode is correct
+    testfile = py.path.local("tests").join("test_hello.py")
+    assert testfile.check()
+    testfile.write("def test_fail(): assert 0")
+    jsonpath = example123.join("res.json")
+    result = cmd("--result-json", jsonpath)
+    assert result.ret == 1
+    data = json.load(jsonpath.open("r"))
+    verify_json_report_format(data)
+    assert re.match(r'.*\W+1\W+failed.*'
+                    r'summary.*'
+                    r'python:\W+commands\W+failed.*', result.out, re.DOTALL)
+
+
+def test_developz(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
     """})
-    result = cmd.run("tox", "-vv", "--develop")
+    result = cmd("-vv", "--develop")
     assert not result.ret
-    assert "sdist-make" not in result.stdout.str()
+    assert "sdist-make" not in result.out
 
 
 def test_usedevelop(initproj, cmd):
@@ -553,9 +547,9 @@ def test_usedevelop(initproj, cmd):
             [testenv]
             usedevelop=True
     """})
-    result = cmd.run("tox", "-vv")
+    result = cmd("-vv")
     assert not result.ret
-    assert "sdist-make" not in result.stdout.str()
+    assert "sdist-make" not in result.out
 
 
 def test_usedevelop_mixed(initproj, cmd):
@@ -567,19 +561,19 @@ def test_usedevelop_mixed(initproj, cmd):
     """})
 
     # running only 'devenv' should not do sdist
-    result = cmd.run("tox", "-vv", "-e", "devenv")
+    result = cmd("-vv", "-e", "devenv")
     assert not result.ret
-    assert "sdist-make" not in result.stdout.str()
+    assert "sdist-make" not in result.out
 
     # running all envs should do sdist
-    result = cmd.run("tox", "-vv")
+    result = cmd("-vv")
     assert not result.ret
-    assert "sdist-make" in result.stdout.str()
+    assert "sdist-make" in result.out
 
 
 @pytest.mark.parametrize("src_root", [".", "src"])
-def test_test_usedevelop(cmd, initproj, src_root):
-    initproj("example123-0.5", src_root=src_root, filedefs={
+def test_test_usedevelop(cmd, initproj, src_root, monkeypatch):
+    base = initproj("example123-0.5", src_root=src_root, filedefs={
         'tests': {
             'test_hello.py': """
                 def test_hello(pytestconfig):
@@ -595,50 +589,45 @@ def test_test_usedevelop(cmd, initproj, src_root):
             deps=pytest
         '''
     })
-    result = cmd.run("tox", "-v")
+    result = cmd("-v")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*junit-python.xml*",
-        "*1 passed*",
-    ])
-    assert "sdist-make" not in result.stdout.str()
-    result = cmd.run("tox", "-epython", )
+    assert re.match(r'.*generated\W+xml\W+file.*junit-python\.xml'
+                    r'.*\W+1\W+passed.*', result.out, re.DOTALL)
+    assert "sdist-make" not in result.out
+    result = cmd("-epython", )
     assert not result.ret
-    assert "develop-inst-noop" in result.stdout.str()
-    result.stdout.fnmatch_lines([
-        "*1 passed*",
-        "*summary*",
-        "*python: commands succeeded"
-    ])
+    assert "develop-inst-noop" in result.out
+    assert re.match(r'.*\W+1\W+passed.*'
+                    r'summary.*'
+                    r'python:\W+commands\W+succeeded.*', result.out, re.DOTALL)
+
     # see that things work with a different CWD
-    old = cmd.tmpdir.chdir()
-    result = cmd.run("tox", "-c", "example123/tox.ini")
+    monkeypatch.chdir(base.dirname)
+    result = cmd("-c", "example123/tox.ini")
     assert not result.ret
-    assert "develop-inst-noop" in result.stdout.str()
-    result.stdout.fnmatch_lines([
-        "*1 passed*",
-        "*summary*",
-        "*python: commands succeeded"
-    ])
-    old.chdir()
+    assert "develop-inst-noop" in result.out
+    assert re.match(r'.*\W+1\W+passed.*'
+                    r'summary.*'
+                    r'python:\W+commands\W+succeeded.*', result.out, re.DOTALL)
+    monkeypatch.chdir(base)
+
     # see that tests can also fail and retcode is correct
     testfile = py.path.local("tests").join("test_hello.py")
     assert testfile.check()
     testfile.write("def test_fail(): assert 0")
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret
-    assert "develop-inst-noop" in result.stdout.str()
-    result.stdout.fnmatch_lines([
-        "*1 failed*",
-        "*summary*",
-        "*python: *failed*",
-    ])
+    assert "develop-inst-noop" in result.out
+    assert re.match(r'.*\W+1\W+failed.*'
+                    r'summary.*'
+                    r'python:\W+commands\W+failed.*', result.out, re.DOTALL)
+
     # test develop is called if setup.py changes
     setup_py = py.path.local("setup.py")
     setup_py.write(setup_py.read() + ' ')
-    result = cmd.run("tox", )
+    result = cmd()
     assert result.ret
-    assert "develop-inst-nodeps" in result.stdout.str()
+    assert "develop-inst-nodeps" in result.out
 
 
 def _alwayscopy_not_supported():
@@ -646,7 +635,9 @@ def _alwayscopy_not_supported():
     # see: https://github.com/pypa/virtualenv/issues/565
     if hasattr(platform, 'linux_distribution'):
         _dist = platform.linux_distribution(full_distribution_name=False)
-        if _dist[0] == 'centos' and _dist[1][0] == '7':
+        (name, version, arch) = _dist
+        if any((name == 'centos' and version[0] == '7',
+                name == 'SuSE' and arch == 'x86_64')):
             return True
     return False
 
@@ -658,9 +649,9 @@ def test_alwayscopy(initproj, cmd):
             commands={envpython} --version
             alwayscopy=True
     """})
-    result = cmd.run("tox", "-vv")
+    result = cmd("-vv")
     assert not result.ret
-    assert "virtualenv --always-copy" in result.stdout.str()
+    assert "virtualenv --always-copy" in result.out
 
 
 def test_alwayscopy_default(initproj, cmd):
@@ -668,9 +659,31 @@ def test_alwayscopy_default(initproj, cmd):
             [testenv]
             commands={envpython} --version
     """})
-    result = cmd.run("tox", "-vv")
+    result = cmd("-vv")
     assert not result.ret
-    assert "virtualenv --always-copy" not in result.stdout.str()
+    assert "virtualenv --always-copy" not in result.out
+
+
+def test_empty_activity_ignored(initproj, cmd):
+    initproj("example123", filedefs={'tox.ini': """
+            [testenv]
+            list_dependencies_command=echo
+            commands={envpython} --version
+    """})
+    result = cmd()
+    assert not result.ret
+    assert "installed:" not in result.out
+
+
+def test_empty_activity_shown_verbose(initproj, cmd):
+    initproj("example123", filedefs={'tox.ini': """
+            [testenv]
+            list_dependencies_command=echo
+            commands={envpython} --version
+    """})
+    result = cmd("-v")
+    assert not result.ret
+    assert "installed:" in result.out
 
 
 def test_test_piphelp(initproj, cmd):
@@ -678,12 +691,12 @@ def test_test_piphelp(initproj, cmd):
         # content of: tox.ini
         [testenv]
         commands=pip -h
-        [testenv:py26]
-        basepython=python
         [testenv:py27]
         basepython=python
+        [testenv:py36]
+        basepython=python
     """})
-    result = cmd.run("tox")
+    result = cmd()
     assert not result.ret
 
 
@@ -693,68 +706,58 @@ def test_notest(initproj, cmd):
         [testenv:py26]
         basepython=python
     """})
-    result = cmd.run("tox", "-v", "--notest")
+    result = cmd("-v", "--notest")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*summary*",
-        "*py26*skipped tests*",
-    ])
-    result = cmd.run("tox", "-v", "--notest", "-epy26")
+    assert re.match(r'.*summary.*'
+                    r'py26\W+skipped\W+tests.*', result.out, re.DOTALL)
+    result = cmd("-v", "--notest", "-epy26")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*py26*reusing*",
-    ])
+    assert re.match(r'.*py26\W+reusing.*', result.out, re.DOTALL)
 
 
 def test_PYC(initproj, cmd, monkeypatch):
     initproj("example123", filedefs={'tox.ini': ''})
     monkeypatch.setenv("PYTHONDOWNWRITEBYTECODE", 1)
-    result = cmd.run("tox", "-v", "--notest")
+    result = cmd("-v", "--notest")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*create*",
-    ])
+    assert 'create' in result.out
 
 
 def test_env_VIRTUALENV_PYTHON(initproj, cmd, monkeypatch):
     initproj("example123", filedefs={'tox.ini': ''})
     monkeypatch.setenv("VIRTUALENV_PYTHON", '/FOO')
-    result = cmd.run("tox", "-v", "--notest")
-    assert not result.ret, result.stdout.lines
-    result.stdout.fnmatch_lines([
-        "*create*",
-    ])
+    result = cmd("-v", "--notest")
+    assert not result.ret, result.outlines
+    assert 'create' in result.out
 
 
 def test_sdistonly(initproj, cmd):
     initproj("example123", filedefs={'tox.ini': """
     """})
-    result = cmd.run("tox", "-v", "--sdistonly")
+    result = cmd("-v", "--sdistonly")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*sdist-make*setup.py*",
-    ])
-    assert "-mvirtualenv" not in result.stdout.str()
+    assert re.match(r'.*sdist-make.*setup.py.*', result.out, re.DOTALL)
+    assert "-mvirtualenv" not in result.out
 
 
-def test_separate_sdist_no_sdistfile(cmd, initproj):
-    distshare = cmd.tmpdir.join("distshare")
+def test_separate_sdist_no_sdistfile(cmd, initproj, tmpdir):
+    distshare = tmpdir.join("distshare")
     initproj(("pkg123-foo", "0.7"), filedefs={
         'tox.ini': """
             [tox]
-            distshare=%s
-        """ % distshare
+            distshare={}
+        """.format(distshare)
     })
-    result = cmd.run("tox", "--sdistonly")
+    result = cmd("--sdistonly")
     assert not result.ret
-    l = distshare.listdir()
-    assert len(l) == 1
-    sdistfile = l[0]
+    distshare_files = distshare.listdir()
+    assert len(distshare_files) == 1
+    sdistfile = distshare_files[0]
     assert 'pkg123-foo-0.7.zip' in str(sdistfile)
 
 
-def test_separate_sdist(cmd, initproj):
-    distshare = cmd.tmpdir.join("distshare")
+def test_separate_sdist(cmd, initproj, tmpdir):
+    distshare = tmpdir.join("distshare")
     initproj("pkg123-0.7", filedefs={
         'tox.ini': """
             [tox]
@@ -762,16 +765,14 @@ def test_separate_sdist(cmd, initproj):
             sdistsrc={distshare}/pkg123-0.7.zip
         """ % distshare
     })
-    result = cmd.run("tox", "--sdistonly")
+    result = cmd("--sdistonly")
     assert not result.ret
-    l = distshare.listdir()
-    assert len(l) == 1
-    sdistfile = l[0]
-    result = cmd.run("tox", "-v", "--notest")
+    sdistfiles = distshare.listdir()
+    assert len(sdistfiles) == 1
+    sdistfile = sdistfiles[0]
+    result = cmd("-v", "--notest")
     assert not result.ret
-    result.stdout.fnmatch_lines([
-        "*inst*%s*" % sdistfile,
-    ])
+    assert "python inst: {}".format(sdistfile) in result.out
 
 
 def test_sdist_latest(tmpdir, newconfig):
@@ -803,11 +804,9 @@ def test_envsitepackagesdir(cmd, initproj):
         commands=
             python -c "print(r'X:{envsitepackagesdir}')"
     """})
-    result = cmd.run("tox")
+    result = cmd()
     assert result.ret == 0
-    result.stdout.fnmatch_lines("""
-        X:*tox*site-packages*
-    """)
+    assert re.match(r'.*\nX:.*tox.*site-packages.*', result.out, re.DOTALL)
 
 
 def test_envsitepackagesdir_skip_missing_issue280(cmd, initproj):
@@ -818,11 +817,9 @@ def test_envsitepackagesdir_skip_missing_issue280(cmd, initproj):
         commands=
             {envsitepackagesdir}
     """})
-    result = cmd.run("tox", "--skip-missing-interpreters")
+    result = cmd("--skip-missing-interpreters")
     assert result.ret == 0
-    result.stdout.fnmatch_lines("""
-        SKIPPED:*qwelkj*
-    """)
+    assert re.match(r'.*SKIPPED:.*qwelkj.*', result.out, re.DOTALL)
 
 
 @pytest.mark.parametrize('verbosity', ['', '-v', '-vv'])
@@ -831,7 +828,7 @@ def test_verbosity(cmd, initproj, verbosity):
         'tox.ini': """
         [testenv]
     """})
-    result = cmd.run("tox", verbosity)
+    result = cmd(verbosity)
     assert result.ret == 0
 
     needle = "Successfully installed pkgX-0.0.5"
@@ -880,15 +877,62 @@ def test_envtmpdir(initproj, cmd):
         '''
     })
 
-    result = cmd.run("tox")
+    result = cmd()
     assert not result.ret
 
-    result = cmd.run("tox")
+    result = cmd()
     assert not result.ret
 
 
 def test_missing_env_fails(initproj, cmd):
     initproj("foo", filedefs={'tox.ini': "[testenv:foo]\ncommands={env:VAR}"})
-    result = cmd.run("tox")
+    result = cmd()
     assert result.ret == 1
-    result.stdout.fnmatch_lines(["*foo: unresolvable substitution(s): 'VAR'*"])
+    assert result.out.endswith("foo: unresolvable substitution(s): 'VAR'."
+                               " Environment variables are missing or defined recursively.\n")
+
+
+def test_tox_console_script():
+    result = subprocess.check_call(['tox', '--help'])
+    assert result == 0
+
+
+def test_tox_quickstart_script():
+    result = subprocess.check_call(['tox-quickstart', '--help'])
+    assert result == 0
+
+
+def test_tox_cmdline_no_args(monkeypatch):
+    monkeypatch.setattr(sys, 'argv', ['caller_script', '--help'])
+    with pytest.raises(SystemExit):
+        tox.cmdline()
+
+
+def test_tox_cmdline_args(monkeypatch):
+    with pytest.raises(SystemExit):
+        tox.cmdline(['caller_script', '--help'])
+
+
+@pytest.mark.parametrize('exit_code', [0, 6])
+def test_exit_code(initproj, cmd, exit_code, mocker):
+    """ Check for correct InvocationError, with exit code,
+        except for zero exit code """
+    mocker.spy(tox, '_exit_code_str')
+    tox_ini_content = "[testenv:foo]\ncommands=python -c 'import sys; sys.exit(%d)'" % exit_code
+    initproj("foo", filedefs={'tox.ini': tox_ini_content})
+    cmd()
+    if exit_code:
+        # need mocker.spy above
+        assert tox._exit_code_str.call_count == 1
+        (args, kwargs) = tox._exit_code_str.call_args
+        assert kwargs == {}
+        (call_error_name, call_command, call_exit_code) = args
+        assert call_error_name == 'InvocationError'
+        # quotes are removed in result.out
+        # do not include "python" as it is changed to python.EXE by appveyor
+        expected_command_arg = ' -c import sys; sys.exit(%d)' % exit_code
+        assert expected_command_arg in call_command
+        assert call_exit_code == exit_code
+    else:
+        # need mocker.spy above
+        assert tox._exit_code_str.call_count == 0
